@@ -4,5 +4,6 @@ var jshint = require('gulp-jshint');
 module.exports = function () {
     gulp.src('./{lib,blocks,components,views}/**/*.js')
         .pipe(jshint())
-        .pipe(jshint.reporter('default'));
+        .pipe(jshint.reporter('default'))
+        .pipe(jshint.reporter('fail'));
 };
