@@ -5,7 +5,9 @@ var blockModels = bulk(__dirname + '/../blocks', '**/*.js');
 module.exports = function Blocks() {
     var self = this;
     for (var id in blockModels) {
-        self[id] = clone(blockModels[id].index.data);
-        self[id].id = id;
+        if(blockModels.hasOwnProperty(id)) {
+            self[id] = clone(blockModels[id].index.data);
+            self[id].id = id;
+        }
     }
 };
