@@ -1,7 +1,5 @@
 var App = require('../../lib/app');
-var templates = require('../../lib/templates.json');
 var view = require('../../lib/view');
-var page = require('page');
 
 module.exports = view.extend({
     id: 'edit',
@@ -19,7 +17,7 @@ module.exports = view.extend({
 
         // Bind app
         self.$data.app = app.data || {};
-        self.$data.onDone = '/make/' + id + '/share';
+        self.$data.onDone = '/make/' + id + '/share?publish=true';
         self.$data.removeApp = function() {
             app.removeApp();
             self.page('/profile');
